Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(584)

Unified Diff: Source/core/css/CSSParser.cpp

Issue 15363004: Rename ShadowDescendant to ShadowPseudo. (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: sync again Created 7 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | Source/core/css/CSSParserValues.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/css/CSSParser.cpp
diff --git a/Source/core/css/CSSParser.cpp b/Source/core/css/CSSParser.cpp
index 273a4afbc6a66fb347ed753dfac2e29c0ccadc61..afd38282f1f58ee546f393c5cad2003f61e77870 100644
--- a/Source/core/css/CSSParser.cpp
+++ b/Source/core/css/CSSParser.cpp
@@ -11091,25 +11091,25 @@ CSSParserSelector* CSSParser::rewriteSpecifiersWithElementName(const AtomicStrin
return specifiers;
}
- CSSParserSelector* lastShadowDescendant = specifiers;
+ CSSParserSelector* lastShadowPseudo = specifiers;
CSSParserSelector* history = specifiers;
while (history->tagHistory()) {
history = history->tagHistory();
- if (history->isCustomPseudoElement() || history->hasShadowDescendant())
- lastShadowDescendant = history;
+ if (history->isCustomPseudoElement() || history->hasShadowPseudo())
+ lastShadowPseudo = history;
}
- if (lastShadowDescendant->tagHistory()) {
+ if (lastShadowPseudo->tagHistory()) {
if (tag != anyQName())
- lastShadowDescendant->tagHistory()->prependTagSelector(tag, tagIsForNamespaceRule);
+ lastShadowPseudo->tagHistory()->prependTagSelector(tag, tagIsForNamespaceRule);
return specifiers;
}
// For shadow-ID pseudo-elements to be correctly matched, the ShadowDescendant combinator has to be used.
// We therefore create a new Selector with that combinator here in any case, even if matching any (host) element in any namespace (i.e. '*').
OwnPtr<CSSParserSelector> elementNameSelector = adoptPtr(new CSSParserSelector(tag));
- lastShadowDescendant->setTagHistory(elementNameSelector.release());
- lastShadowDescendant->setRelation(CSSSelector::ShadowDescendant);
+ lastShadowPseudo->setTagHistory(elementNameSelector.release());
+ lastShadowPseudo->setRelation(CSSSelector::ShadowPseudo);
return specifiers;
}
@@ -11136,12 +11136,12 @@ CSSParserSelector* CSSParser::rewriteSpecifiers(CSSParserSelector* specifiers, C
{
if (newSpecifier->isCustomPseudoElement() || newSpecifier->pseudoType() == CSSSelector::PseudoCue) {
// Unknown pseudo element always goes at the top of selector chain.
- newSpecifier->appendTagHistory(CSSSelector::ShadowDescendant, sinkFloatingSelector(specifiers));
+ newSpecifier->appendTagHistory(CSSSelector::ShadowPseudo, sinkFloatingSelector(specifiers));
return newSpecifier;
}
if (specifiers->isCustomPseudoElement()) {
// Specifiers for unknown pseudo element go right behind it in the chain.
- specifiers->insertTagHistory(CSSSelector::SubSelector, sinkFloatingSelector(newSpecifier), CSSSelector::ShadowDescendant);
+ specifiers->insertTagHistory(CSSSelector::SubSelector, sinkFloatingSelector(newSpecifier), CSSSelector::ShadowPseudo);
return specifiers;
}
specifiers->appendTagHistory(CSSSelector::SubSelector, sinkFloatingSelector(newSpecifier));
@@ -11091,25 +11091,25 @@ CSSParserSelector* CSSParser::rewriteSpecifiersWithElementName(const AtomicStrin
return specifiers;
}
- // For shadow-ID pseudo-elements to be correctly matched, the ShadowDescendant combinator has to be used.
+ // For shadow-ID pseudo-elements to be correctly matched, the ShadowPseudo combinator has to be used.
// We therefore create a new Selector with that combinator here in any case, even if matching any (host) element in any namespace (i.e. '*').
OwnPtr<CSSParserSelector> elementNameSelector = adoptPtr(new CSSParserSelector(tag));
« no previous file with comments | « no previous file | Source/core/css/CSSParserValues.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698